Crate aoflagger_sys

Crate aoflagger_sys 

Structs

CxxAOFlagger
CXX Wrapper for aoflagger::AOFlagger, the main class for access to the flagger functionality.
CxxFlagMask
CXX Wrapper for aoflagger::FlagMask, a two-dimensional mask of bool flags.
CxxImageSet
CXX Wrapper for aoflagger::ImageSet, a set of time-frequency ‘images’ which together contain data for one correlated baseline.
CxxStrategy
CXX Wrapper for aoflagger::Strategy, a flagging strategy definition.
UniquePtr
Binding to C++ std::unique_ptr<T, std::default_delete<T>>.

Functions

cxx_aoflagger_new
Create a new CxxAOFlagger instance
flagmask_or
Perform the binary or operation on the flag buffer of this_flagmask with the buffer of other_flagmask, storing the result in this_flagmask
flagmask_set
Set the flag buffer of this_flagmask from the buffer of other_flagmask, storing the result in this_flagmask