CxxImageSet

Struct CxxImageSet 

#[repr(C)]
pub struct CxxImageSet { /* private fields */ }
CXX Wrapper for aoflagger::ImageSet, a set of time-frequency ‘images’ which together contain data for one correlated baseline.

Please see the aoflagger documentation for more details.

Implementations

Source

impl CxxImageSet

pub fn Width(&self) -> usize

Get the width (number of timesteps) of the CxxImageSet

Source

impl CxxImageSet

pub fn Height(&self) -> usize

Get the height (number of coarse × fine frequency channels) of the CxxImageSet

Source

impl CxxImageSet

pub fn ImageCount(&self) -> usize

Get the count (number of polarizations × complex components) of the CxxImageSet

Source

impl CxxImageSet

pub fn HorizontalStride(&self) -> usize

Get the total number of floats in one row of the CxxImageSet

Row might have been padded to allow for SSE instructions and other optimizations. Therefore, one should add the horizontal stride to a data pointer to get the float in the next row (channel).

Source

impl CxxImageSet

pub fn ImageBuffer(&self, imgIndex: usize) -> &[f32]

(Immutably) access the raw float buffer at imgIndex in the CxxImageSet

Source

impl CxxImageSet

pub fn ImageBufferMut(self: Pin<&mut Self>, imgIndex: usize) -> &mut [f32]

(Mutably) access the raw float buffer at imgIndex in the CxxImageSet

Source

impl CxxImageSet

pub unsafe fn ImageBufferMutUnsafe(&self, imgIndex: usize) -> &mut [f32]

(Mutably) access the raw float buffer at imgIndex in the CxxImageSet without pins

Safety

TODO: document safety